@@ -16,9 +16,6 @@
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
-#[cfg(all(feature = "std", feature = "alloc"))]
-compile_error!(r#"Cannot compile both features "std" and "alloc""#);
-
 #[cfg(all(not(feature = "std"), not(feature = "alloc")))]
 compile_error!(r#"The "no_std" feature currently requires the "alloc" feature"#);
 
@@ -29,6 +26,8 @@ extern crate core;
 #[macro_use]
 extern crate alloc;
 
+pub use async_trait::async_trait;
+
 pub extern crate hashbrown;
 
 #[allow(unused_imports)]
@@ -92,4 +91,14 @@ pub mod traits {
         /// Try cloning a object and return an `Err` in case of failure.
         async fn async_try_clone(&self) -> Result<Self>;
     }
+
+    #[async_trait]
+    impl<D> AsyncTryClone for D
+    where
+        D: Clone + Sync,
+    {
+        async fn async_try_clone(&self) -> Result<Self> {
+            Ok(self.clone())
+        }
+    }
 }
